# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-FileHandle-Fmode
Version:	0.15
Release:	1.%{__distinit}%{__distvers}
Summary:	Determine whether a filehandle is opened for reading, writing, or both
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/FileHandle-Fmode
Source0:	https://cpan.metacpan.org/modules/by-module/FileHandle/FileHandle-Fmode-%{version}.tar.gz
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(warnings)
# Module Runtime
BuildRequires:	perl(Config)
BuildRequires:	perl(constant)
BuildRequires:	perl(DynaLoader)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(Fcntl)
BuildRequires:	perl(strict)
# Test Suite
BuildRequires:	perl(Pod::Simple)
BuildRequires:	perl(Test::Pod) >= 1.00
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

# Don't "provide" private Perl libs
%{?perl_default_filter}

%description
Determine whether a filehandle is opened for reading, writing, or both.

%prep
%setup -q -n FileHandle-Fmode-%{version}

# Tarball probably made on Windows
chmod -c -x CHANGES Fmode.pm Fmode.xs Makefile.PL MANIFEST README

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc CHANGES README
%{perl_vendorarch}/auto/FileHandle/
%{perl_vendorarch}/FileHandle/
%{_mandir}/man3/FileHandle::Fmode.3*

%changelog
* Wed Jun 19 2024 Paul Howarth <paul@city-fan.org> - 0.15-1
- Update to 0.15
  - Documentation improvements
  - Avoid win32_fmode() when perl is built by UCRT compiler, as UCRT changes
    struct _iobuf (affects MSWin32 only)
- Remove bogus exec permissions on source files

* Thu Jun 13 2024 Paul Howarth <paul@city-fan.org> - 0.14-28
- Perl 5.40 rebuild

* Tue Jul 11 2023 Paul Howarth <paul@city-fan.org> - 0.14-24
- Perl 5.38 rebuild

* Mon Mar 13 2023 Paul Howarth <paul@city-fan.org> - 0.14-23
- Use SPDX-format license tag

* Wed Jun  1 2022 Paul Howarth <paul@city-fan.org> - 0.14-21
- Perl 5.36 rebuild

* Fri May 21 2021 Paul Howarth <paul@city-fan.org> - 0.14-18
- Perl 5.34 rebuild

* Thu Jun 25 2020 Paul Howarth <paul@city-fan.org> - 0.14-15
- Perl 5.32 rebuild

* Fri May 31 2019 Paul Howarth <paul@city-fan.org> - 0.14-12
- Perl 5.30 rebuild

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 0.14-9
- Perl 5.28 rebuild

* Wed Mar 28 2018 Paul Howarth <paul@city-fan.org> - 0.14-8
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally

* Wed Aug 24 2016 Paul Howarth <paul@city-fan.org> - 0.14-3
- Classify buildreqs by usage
- Simplify find commands using -empty and -delete

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> - 0.14-2
- Perl 5.20 rebuild

* Thu Aug 14 2014 Paul Howarth <paul@city-fan.org> - 0.14-1
- Update to 0.14
  - Define PERL_NO_GET_CONTEXT
- Specify all dependencies
- No longer need to fix line endings of documentation files
- Drop %%defattr, redundant since rpm 4.4

* Mon Nov  5 2012 Paul Howarth <paul@city-fan.org> - 0.13-1
- Update to 0.13
  - Fix Hurd compatibility (CPAN RT#80607)

* Fri Oct  5 2012 Paul Howarth <paul@city-fan.org> - 0.12-1
- Update to 0.12
  - Avoid modifying global $_ (CPAN RT#79983)
- BR: perl(Test::Pod) ≥ 1.00

* Fri Jun  8 2012 Paul Howarth <paul@city-fan.org> - 0.11-5
- BR: perl(Exporter)
- Use pure_install rather than install
- Don't need to remove empty directories from buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Mon Jun 27 2011 Paul Howarth <paul@city-fan.org> - 0.11-4
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 0.11-3
- Rebuild for perl 5.12.1 in Rawhide

* Wed May 19 2010 Paul Howarth <paul@city-fan.org> - 0.11-2
- Fix dist tag for RHEL-6 Beta

* Fri Feb  5 2010 Paul Howarth <paul@city-fan.org> - 0.11-1
- Import from Fedora
- Update to 0.11
  - Add is_FH(), which is an alias for is_arg_ok()
  - Various minor adjustments to enable trouble-free building on pre-5.6
  - Add copyright notice to the LICENSE section of the pod

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.09-7
- Rebuild against perl 5.10.1

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.09-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.09-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Mar 06 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.09-4
- Rebuild for new perl

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0.09-3
- Autorebuild for GCC 4.3

* Thu Mar 22 2007 Andreas Thienemann <andreas@bawue.net> - 0.09-2
- Fixed EOL-encoding in the packages %%doc files

* Sat Mar 10 2007 Andreas Thienemann <andreas@bawue.net> - 0.09-1
- Specfile autogenerated by cpanspec 1.69.1
